summaryrefslogtreecommitdiffstats
path: root/libkcal/tests/testresource.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/tests/testresource.cpp')
-rw-r--r--libkcal/tests/testresource.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkcal/tests/testresource.cpp b/libkcal/tests/testresource.cpp
index 68251869..5779c47b 100644
--- a/libkcal/tests/testresource.cpp
+++ b/libkcal/tests/testresource.cpp
@@ -55,8 +55,8 @@ static const KCmdLineOptions options[] =
int main(int argc, char *argv[])
{
// Use another directory than the real one, just to keep things clean
- // KDEHOME needs to be writable though, for a ksycoca database
- setenv( "KDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testresource" ), true );
+ // TDEHOME needs to be writable though, for a ksycoca database
+ setenv( "TDEHOME", TQFile::encodeName( TQDir::homeDirPath() + "/.kde-testresource" ), true );
setenv( "KDE_FORK_SLAVES", "yes", true ); // simpler, for the final cleanup
KApplication::disableAutoDcopRegistration();